pyramid_localize
================

Package to provide translation methods for pyramid, and means to reload translations without stopping the application

.. image:: https://travis-ci.org/fizyk/pyramid_localize.png?branch=master
    :target: https://travis-ci.org/fizyk/pyramid_localize
    :alt: Tests for RandomWords

.. image:: https://coveralls.io/repos/fizyk/pyramid_localize/badge.png?branch=master
    :target: https://coveralls.io/r/fizyk/pyramid_localize?branch=master
    :alt: Coverage Status

.. image:: https://pypip.in/v/pyramid_localize/badge.png
    :target: https://crate.io/packages/pyramid_localize/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/pyramid_localize/badge.png
    :target: https://crate.io/packages/pyramid_localize/
    :alt: Number of PyPI downloads

Documentation can be found on `readthedocs.org <https://pyramid_localize.readthedocs.org/en/latest/>`_.


Instalation:
============

``pip install pyramid_localize``

or add **pyramid_localize** to your **setup.py** requirements.


Tests:
======

You'll need: **nose**, **WebTest**, **coverage** to run tests, and then:

``python setup.py nosetests``
